==> haskell-direct-sqlite-2.3.29-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 direct-sqlite
version:              2.3.29
visibility:           public
id:                   direct-sqlite-2.3.29-Ioz0fiGOVqFGsU5fx15d4m
key:                  direct-sqlite-2.3.29-Ioz0fiGOVqFGsU5fx15d4m
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak,
    2022        Joshua Chia

maintainer:           Joshua Chia <joshchia@gmail.com>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  f09e3f88a48b7d13e9d56987dc3bbf2c
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs:         /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-direct-sqlite
hs-libraries:         HSdirect-sqlite-2.3.29-Ioz0fiGOVqFGsU5fx15d4m
extra-libraries:      sqlite3
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-direct-sqlite-2.3.29-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 direct-sqlite
version:              2.3.29
visibility:           public
id:                   direct-sqlite-2.3.29-1iY8liTjVUk5orKhe8yD2u
key:                  direct-sqlite-2.3.29-1iY8liTjVUk5orKhe8yD2u
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak,
    2022        Joshua Chia

maintainer:           Joshua Chia <joshchia@gmail.com>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  31d258dfdd8276496e8be3a9f5b13ea8
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs:         /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-direct-sqlite
hs-libraries:         HSdirect-sqlite-2.3.29-1iY8liTjVUk5orKhe8yD2u
extra-libraries:      sqlite3
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
